@@ -22,8 +22,10 @@ use crate::{
 };
 
 // TODO:
+// * Replace proc-macro-error dep with syn::Result
+// * Decouple enum and flags generation from key generation, make them standalone
 // * Use `quote_spanned` where applicable for better error propagation on generated code
-// * Remove serde and deluxe dependencies
+// * Remove serde and deluxe dependencies (consider using quick-xml directly or xmlserde)
 // * Improve enum generation (create enum based on its definition, instead of by key; also add doc alias for its id)
 // * Add way to map setter and getters value
 // * Add `bind_#key writable`, `user_#key_value`, `connect_#key_writable_changed` variants
@@ -296,7 +298,7 @@ pub fn gen_settings(
     let schema_file_path = SpannedValue::into_inner(file_attr);
 
     // Parse schema list
-    let schema_file = File::open(&schema_file_path).unwrap_or_else(|err| {
+    let schema_file = File::open(schema_file_path).unwrap_or_else(|err| {
         abort!(file_attr_span, "failed to open schema file: {}", err);
     });
     let schema_list: SchemaList = quick_xml::de::from_reader(BufReader::new(schema_file))
